@@ -2,9 +2,9 @@
 from telliot_core.datafeed import DataFeed
 from telliot_core.queries import LegacyRequest
 
-from telliot_feed_examples.sources.bitfinex import BitfinexPriceSource
-from telliot_feed_examples.sources.bitflyer import BitflyerPriceSource
-from telliot_feed_examples.sources.coingecko import CoinGeckoPriceSource
+from telliot_feed_examples.sources.price.spot.bitfinex import BitfinexSpotPriceSource
+from telliot_feed_examples.sources.price.spot.bitflyer import BitflyerSpotPriceSource
+from telliot_feed_examples.sources.price.spot.coingecko import CoinGeckoSpotPriceSource
 from telliot_feed_examples.sources.price_aggregator import PriceAggregator
 
 eth_jpy_median_feed = DataFeed(
@@ -14,9 +14,9 @@ eth_jpy_median_feed = DataFeed(
         currency="jpy",
         algorithm="median",
         sources=[
-            CoinGeckoPriceSource(asset="eth", currency="jpy"),
-            BitflyerPriceSource(asset="eth", currency="jpy"),
-            BitfinexPriceSource(asset="eth", currency="jpy"),
+            CoinGeckoSpotPriceSource(asset="eth", currency="jpy"),
+            BitflyerSpotPriceSource(asset="eth", currency="jpy"),
+            BitfinexSpotPriceSource(asset="eth", currency="jpy"),
         ],
     ),
 )
