@@ -1,7 +1,7 @@
 from telliot_core.datafeed import DataFeed
 from telliot_core.queries import SpotPrice
 
-from telliot_feed_examples.sources.coingecko import CoinGeckoPriceSource
+from telliot_feed_examples.sources.price.spot.coingecko import CoinGeckoSpotPriceSource
 from telliot_feed_examples.sources.price_aggregator import PriceAggregator
 
 ohm_eth_median_feed = DataFeed(
@@ -10,6 +10,6 @@ ohm_eth_median_feed = DataFeed(
         asset="ohm",
         currency="eth",
         algorithm="median",
-        sources=[CoinGeckoPriceSource(asset="ohm", currency="eth")],
+        sources=[CoinGeckoSpotPriceSource(asset="ohm", currency="eth")],
     ),
 )
