@@ -2,7 +2,7 @@
 from telliot_core.datafeed import DataFeed
 from telliot_core.queries import LegacyRequest
 
-from telliot_feed_examples.sources.coingecko import CoinGeckoPriceSource
+from telliot_feed_examples.sources.price.spot.coingecko import CoinGeckoSpotPriceSource
 from telliot_feed_examples.sources.price_aggregator import PriceAggregator
 
 trb_usd_median_feed = DataFeed(
@@ -12,7 +12,7 @@ trb_usd_median_feed = DataFeed(
         currency="usd",
         algorithm="median",
         sources=[
-            CoinGeckoPriceSource(asset="trb", currency="usd"),
+            CoinGeckoSpotPriceSource(asset="trb", currency="usd"),
         ],
     ),
 )
