@@ -8,18 +8,21 @@ from typing import Optional
 from typing import Tuple
 from typing import Union
 
-from eth_account.account import Account
-from eth_account.signers.local import LocalAccount
+from chained_accounts import ChainedAccount
+from eth_utils import to_checksum_address
 from telliot_core.contract.contract import Contract
-from telliot_core.contract.gas import ethgasstation
 from telliot_core.datafeed import DataFeed
 from telliot_core.gas.etherscan_gas import EtherscanGasPriceSource
+from telliot_core.gas.legacy_gas import ethgasstation
 from telliot_core.model.endpoints import RPCEndpoint
+from telliot_core.reporters.reporter_utils import tellor_suggested_report
+from telliot_core.utils.key_helpers import lazy_unlock_account
 from telliot_core.utils.response import error_status
 from telliot_core.utils.response import ResponseStatus
 from web3 import Web3
 from web3.datastructures import AttributeDict
 
+from telliot_feed_examples.feeds import CATALOG_FEEDS
 from telliot_feed_examples.feeds.eth_usd_feed import eth_usd_median_feed
 from telliot_feed_examples.feeds.trb_usd_feed import trb_usd_median_feed
 from telliot_feed_examples.utils.log import get_logger
@@ -30,16 +33,16 @@ logger = get_logger(__name__)
 
 class IntervalReporter:
     """Reports values from given datafeeds to a TellorX Oracle
-    every 10 seconds."""
+    every 7 seconds."""
 
     def __init__(
         self,
         endpoint: RPCEndpoint,
-        private_key: str,
+        account: ChainedAccount,
         chain_id: int,
         master: Contract,
         oracle: Contract,
-        datafeed: DataFeed[Any],
+        datafeed: Optional[DataFeed[Any]] = None,
         expected_profit: Union[str, float] = 100.0,
         transaction_type: int = 0,
         gas_limit: int = 350000,
@@ -50,11 +53,12 @@ class IntervalReporter:
     ) -> None:
 
         self.endpoint = endpoint
+        self.account = account
         self.master = master
         self.oracle = oracle
         self.datafeed = datafeed
         self.chain_id = chain_id
-        self.user = self.endpoint.web3.eth.account.from_key(private_key).address
+        self.acct_addr = to_checksum_address(account.address)
         self.last_submission_timestamp = 0
         self.expected_profit = expected_profit
         self.transaction_type = transaction_type
@@ -64,10 +68,7 @@ class IntervalReporter:
         self.legacy_gas_price = legacy_gas_price
         self.gas_price_speed = gas_price_speed
 
-        logger.info(f"Reporting with account: {self.user}")
-
-        self.account: LocalAccount = Account.from_key(private_key)
-        assert self.user == self.account.address
+        logger.info(f"Reporting with account: {self.acct_addr}")
 
     async def check_reporter_lock(self) -> ResponseStatus:
         """Ensure enough time has passed since last report
@@ -79,7 +80,7 @@ class IntervalReporter:
         # Save last submission timestamp to reduce web3 calls
         if self.last_submission_timestamp == 0:
             last_timestamp, read_status = await self.oracle.read(
-                "getReporterLastTimestamp", _reporter=self.user
+                "getReporterLastTimestamp", _reporter=self.acct_addr
             )
 
             # Log web3 errors
@@ -104,9 +105,9 @@ class IntervalReporter:
 
         return status
 
-    async def fetch_gas_price(self) -> int:
+    async def fetch_gas_price(self, speed: str = "average") -> int:
         """Fetch gas price from ethgasstation in gwei."""
-        return await ethgasstation(style="average")  # type: ignore
+        return await ethgasstation(speed)  # type: ignore
 
     async def ensure_staked(self) -> Tuple[bool, ResponseStatus]:
         """Make sure the current user is staked
@@ -118,7 +119,7 @@ class IntervalReporter:
         gas_price_gwei = await self.fetch_gas_price()
 
         staker_info, read_status = await self.master.read(
-            func_name="getStakerInfo", _staker=self.user
+            func_name="getStakerInfo", _staker=self.acct_addr
         )
 
         if (not read_status.ok) or (staker_info is None):
@@ -139,41 +140,38 @@ class IntervalReporter:
         elif staker_info[0] == 0:
             logger.info("Address not yet staked. Depositing stake.")
 
-            _, write_status = await self.master.write_with_retry(
+            _, write_status = await self.master.write(
                 func_name="depositStake",
                 gas_limit=350000,
-                gas_price=gas_price_gwei,
-                extra_gas_price=20,
-                retries=5,
+                legacy_gas_price=gas_price_gwei,
             )
 
             if write_status.ok:
                 return True, status
             else:
-                status.error = (
-                    "Unable to stake deposit: " + write_status.error
+                msg = (
+                    "Unable to stake deposit: "
+                    + write_status.error
+                    + f"Make sure {self.acct_addr} has enough ETH & TRB (100)"
                 )  # error won't be none # noqa: E501
-                logger.error(status.error)
-                status.e = write_status.e
-                return False, status
+                return False, error_status(msg, log=logger.info)
 
         # Status 3: disputed
         if staker_info[0] == 3:
-            status.error = "Current address disputed. Switch address to continue reporting."  # noqa: E501
-            logger.info(status.error)
-            status.e = None
-            return False, status
+            msg = "Current address disputed. Switch address to continue reporting."  # noqa: E501
+            return False, error_status(msg, log=logger.info)
 
         # Statuses 2, 4, and 5: stake transition
         else:
-            status.error = (
+            msg = (
                 "Current address is locked in dispute or for withdrawal."  # noqa: E501
             )
-            logger.info(status.error)
-            status.e = None
-            return False, status
+            return False, error_status(msg, log=logger.info)
 
-    async def ensure_profitable(self) -> ResponseStatus:
+    async def ensure_profitable(
+        self,
+        datafeed: DataFeed[Any],
+    ) -> ResponseStatus:
         """Estimate profitability
 
         Returns a bool signifying whether submitting for a given
@@ -182,7 +180,7 @@ class IntervalReporter:
 
         # Get current tips and time-based reward for given queryID
         rewards, read_status = await self.oracle.read(
-            "getCurrentReward", _queryId=self.datafeed.query.query_id
+            "getCurrentReward", _queryId=datafeed.query.query_id
         )
 
         # Log web3 errors
@@ -279,6 +277,26 @@ class IntervalReporter:
         result = await c.fetch_new_datapoint()
         return result
 
+    async def fetch_datafeed(self) -> DataFeed[Any]:
+        if self.datafeed is not None:
+            datafeed = self.datafeed
+        else:
+            suggested_qtag = await tellor_suggested_report(self.oracle)
+            if not suggested_qtag:
+                msg = "Could not get suggested query."
+                return None, error_status(msg, log=logger.info)
+            datafeed = CATALOG_FEEDS[suggested_qtag]
+
+        return datafeed
+
+    async def get_num_reports_by_id(
+        self, query_id: bytes
+    ) -> Tuple[int, ResponseStatus]:
+        count, read_status = await self.oracle.read(
+            func_name="getTimestampCountById", _queryId=query_id
+        )
+        return count, read_status
+
     async def report_once(
         self,
     ) -> Tuple[Optional[AttributeDict[Any, Any]], ResponseStatus]:
@@ -296,21 +314,28 @@ class IntervalReporter:
         if not status.ok:
             return None, status
 
-        status = await self.ensure_profitable()
+        # Get suggested datafeed if none provided
+        datafeed = await self.fetch_datafeed()
+
+        logger.info(f"Current query: {datafeed.query.descriptor}")
+
+        status = await self.ensure_profitable(datafeed)
         if not status.ok:
             return None, status
 
         status = ResponseStatus()
 
+        address = to_checksum_address(self.account.address)
+
         # Update datafeed value
-        await self.datafeed.source.fetch_new_datapoint()
-        latest_data = self.datafeed.source.latest
+        await datafeed.source.fetch_new_datapoint()
+        latest_data = datafeed.source.latest
         if latest_data[0] is None:
             msg = "Unable to retrieve updated datafeed value."
             return None, error_status(msg, log=logger.info)
 
         # Get query info & encode value to bytes
-        query = self.datafeed.query
+        query = datafeed.query
         query_id = query.query_id
         query_data = query.query_data
         try:
@@ -320,12 +345,11 @@ class IntervalReporter:
             return None, error_status(msg, e=e, log=logger.error)
 
         # Get nonce
-        timestamp_count, read_status = await self.oracle.read(
-            func_name="getTimestampCountById", _queryId=query_id
-        )
+        report_count, read_status = await self.get_num_reports_by_id(query_id)
+
         if not read_status.ok:
             status.error = (
-                "Unable to retrieve timestampCount: " + read_status.error
+                "Unable to retrieve report count: " + read_status.error
             )  # error won't be none # noqa: E501
             logger.error(status.error)
             status.e = read_status.e
@@ -336,10 +360,10 @@ class IntervalReporter:
         submit_val_tx = submit_val_func(
             _queryId=query_id,
             _value=value,
-            _nonce=timestamp_count,
+            _nonce=report_count,
             _queryData=query_data,
         )
-        acc_nonce = self.endpoint._web3.eth.get_transaction_count(self.account.address)
+        acc_nonce = self.endpoint._web3.eth.get_transaction_count(address)
 
         # Add transaction type 2 (EIP-1559) data
         if self.transaction_type == 2:
@@ -362,16 +386,24 @@ class IntervalReporter:
             )
         # Add transaction type 0 (legacy) data
         else:
+            # Fetch legacy gas price if not provided by user
+            if not self.legacy_gas_price:
+                gas_price = await self.fetch_gas_price(self.gas_price_speed)
+            else:
+                gas_price = self.legacy_gas_price
+
             built_submit_val_tx = submit_val_tx.buildTransaction(
                 {
                     "nonce": acc_nonce,
                     "gas": self.gas_limit,
-                    "gasPrice": Web3.toWei(self.legacy_gas_price, "gwei"),  # type: ignore
+                    "gasPrice": Web3.toWei(gas_price, "gwei"),
                     "chainId": self.chain_id,
                 }
             )
 
-        tx_signed = self.account.sign_transaction(built_submit_val_tx)  # type: ignore
+        lazy_unlock_account(self.account)
+        local_account = self.account.local_account
+        tx_signed = local_account.sign_transaction(built_submit_val_tx)
 
         try:
             logger.debug("Sending submitValue transaction")
