@@ -1,6 +1,5 @@
 import logging
 import pathlib
-import sys
 from pathlib import Path
 
 from telliot_core.apps.telliot_config import TelliotConfig
@@ -45,23 +44,6 @@ def get_logger(name: str) -> logging.Logger:
     _ = get_logger(name=__name__)
     """
     logger = logging.getLogger(name)
-
-    logger.setLevel(level=cfg.main.loglevel)
-
-    logs_file = default_logsdir() / ("telliot-feed-examples.log")
-    logs_file = logs_file.resolve().absolute()
-
-    output_file_handler = logging.FileHandler(logs_file)
-    stdout_handler = logging.StreamHandler(sys.stdout)
-
-    formatter = logging.Formatter(
-        "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
-    )
-    output_file_handler.setFormatter(formatter)
-    stdout_handler.setFormatter(formatter)
-
-    logger.addHandler(output_file_handler)
-    logger.addHandler(stdout_handler)
     logger.addFilter(DuplicateFilter())
 
     return logger
